@@ -5,6 +5,7 @@ import os
 import random
 import re
 import sys
+from encodings.aliases import aliases
 from functools import reduce, wraps
 from importlib import import_module
 from inspect import currentframe
@@ -145,8 +146,10 @@ def add(ename, encode=None, decode=None, pattern=None, text=True, add_to_codecs=
         ci.parameters['add_to_codecs'] = add_to_codecs
         ci.parameters['pattern'] = pattern
         ci.parameters['text'] = text
-        ci.parameters['type'] = kwargs.get('type', glob['__file__'].split(os.path.sep)[-2].rstrip("s"))
+        f = glob.get('__file__', os.path.join("custom", "_"))
+        ci.parameters['category'] = kwargs.get('category', f.split(os.path.sep)[-2].rstrip("s"))
         ci.parameters['examples'] = kwargs.get('examples', glob.get('__examples__'))
+        ci.parameters['module'] = kwargs.get('module', glob.get('__name__'))
         return ci
     
     getregentry.__name__ = re.sub(r"[\s\-]", "_", ename)
@@ -154,7 +157,7 @@ def add(ename, encode=None, decode=None, pattern=None, text=True, add_to_codecs=
     register(getregentry, add_to_codecs)
 
 
-def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=False, binary=False, **kwargs):
+def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=False, intype=None, outype=None, **kwargs):
     """
     This adds a new mapping codec (that is, declarable with a simple character mapping dictionary) to the codecs module
      dynamically setting its encode and/or decode functions, eventually dynamically naming the encoding with a pattern
@@ -169,16 +172,23 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                            - while decoding, separators can be mixed in the input text
     :param ignore_case:   ignore text case while encoding and/or decoding
     :param no_error:      this encoding triggers no error (hence, always in "leave" errors handling)
-    :param binary:        encoding applies to the binary string of the input text
+    :param intype:        specify the input type for pre-transforming the input text
+    :param outype:        specify the output type for post-transforming the output text
     :param pattern:       pattern for dynamically naming the encoding
     :param text:          specify whether the codec is a text encoding
     :param add_to_codecs: also add the search function to the native registry
                            NB: this will make the codec available in the built-in open(...) but will make it impossible
                                 to remove the codec later
     """
+    outype = outype or intype
     if ignore_case not in [None, "encode", "decode", "both"]:
         raise ValueError("Bad ignore_case parameter while creating encoding map")
-    def __generic_code(exc, decode=False):
+    if intype not in [None, "str", "bin", "ord"]:
+        raise ValueError("Bad input type parameter while creating encoding map")
+    if outype not in [None, "str", "bin", "ord"]:
+        raise ValueError("Bad output type parameter while creating encoding map")
+    
+    def __generic_code(decode=False):
         def _wrapper(param):
             """
             The parameter for wrapping comes from the encoding regex pattern ; e.g.
@@ -216,6 +226,7 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                     # no 'else' handling a LookupError here ; this case is covered by the first if/elif/else block
                 # case 2: list or dictionary or dictionary of numbered encodings
                 elif isinstance(p, int):
+                    # if mapdict is a list, we shall align the parameter (starting from 1) as an index (starting from 0)
                     if isinstance(mapdict, list):
                         p -= 1
                     if isinstance(mapdict, list) and 0 <= p < len(mapdict) or \
@@ -227,7 +238,7 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                 elif isinstance(mapdict, dict) and isinstance(list(mapdict.values())[0], dict):
                     tmp = None
                     for r, d in mapdict.items():
-                        if r == '':   # this is already handled in case 1 ; anyway, an empty regex always match, hence
+                        if r == '':   # this is already handled in case 1 ; anyway, an empty regex always matches, hence
                             continue  #  it must be excluded
                         if re.match(r, p):
                             tmp = d
@@ -241,29 +252,37 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                     base_tokens = ""
                     for _, c in sorted(mapdict.items()):
                         for t in c:
-                            if t not in base_tokens:
-                                base_tokens += t
+                            for st in t:
+                                if st not in base_tokens:
+                                    base_tokens += st
+                    if " " not in sep:
+                        base_tokens = base_tokens.replace(" ", "")
                     if len(p) > 0 and p[0] in "-_" and len(p[1:]) == len(set(p[1:])) == len(base_tokens):
                         p = p[1:]
                     if len(p) == len(set(p)) == len(base_tokens):
                         t = maketrans(base_tokens, p)
                         for k, v in smapdict.items():
-                            smapdict[k] = v.translate(t)
+                            smapdict[k] = [x.translate(t) for x in v] if isinstance(v, list) else v.translate(t)
                     else:
                         raise LookupError("Bad parameter for encoding '{}': '{}'".format(ename, p))
             if ignore_case is not None:
-                case_d = ["upper", "lower"][any(c in "".join(smapdict.values()) for c in "abcdefghijklmnopqrstuvwxyz")]
-                case_e = ["upper", "lower"][any(c in "".join(smapdict.keys()) for c in "abcdefghijklmnopqrstuvwxyz")]
+                cases = ["upper", "lower"]
+                case_d = cases[any(c in str(list(smapdict.values())) for c in "abcdefghijklmnopqrstuvwxyz")]
+                case_e = cases[any(c in str(list(smapdict.keys())) for c in "abcdefghijklmnopqrstuvwxyz")]
                 i = ignore_case
                 smapdict = {getattr(k, case_e)() if i in ["both", "encode"] else k: \
-                            getattr(v, case_d)() if i in ["both", "decode"] else v for k, v in smapdict.items()}
+                            ([getattr(x, case_d)() for x in v] if isinstance(v, list) else getattr(v, case_d)()) \
+                                if i in ["both", "decode"] else v for k, v in smapdict.items()}
             if decode:
                 tmp = {}
                 # this has a meaning for encoding maps that could have clashes in encoded chars (e.g. Bacon's cipher ;
                 #  I => abaaa but also J => abaaa, with the following, we keep I instead of letting J overwrite it)
                 for k, v in sorted(smapdict.items()):
-                    if v not in tmp.keys():
-                        tmp[v] = k
+                    if not isinstance(v, list):
+                        v = [v]
+                    for x in v:
+                        if x not in tmp.keys():
+                            tmp[x] = k
                 smapdict = tmp
             # this allows to avoid an error with Python2 in the "for i, c in enumerate(parts)" loop
             if '' not in smapdict.keys():
@@ -271,7 +290,10 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
             # determine token and result lengths
             tmaxlen = max(map(len, smapdict.keys()))
             tminlen = max(1, min(map(len, set(smapdict.keys()) - {''})))
-            rminlen = max(1, min(map(len, set(smapdict.values()) - {''})))
+            l = []
+            for x in smapdict.values():
+                getattr(l, ["append", "extend"][isinstance(x, list)])(x)
+            rminlen = max(1, min(map(len, set(l) - {''})))
             
             # generic encoding/decoding function for map encodings
             def code(text, errors="strict"):
@@ -283,20 +305,27 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                 if no_error:
                     errors = "leave"
                 text = ensure_str(text)
-                if binary and not decode:
-                    text = "".join("{:0>8}".format(bin(ord(c))[2:]) for c in text)
+                if not decode:
+                    if intype == "bin":
+                        text = "".join("{:0>8}".format(bin(ord(c))[2:]) for c in text)
+                    elif intype == "ord":
+                        text = "".join(str(ord(c)).zfill(3) for c in text)
                 r = ""
                 lsep = "" if decode else sep if len(sep) <= 1 else sep[0]
+                error_func = handle_error(ename, errors, lsep, repl_char, rminlen, decode)
                 
                 # get the value from the mapping dictionary, trying the token with its inverted case if relevant
                 def __get_value(token, position, case_changed=False):
                     try:
-                        return smapdict[token] + lsep
+                        result = smapdict[token]
                     except KeyError:
                         if icase and not case_changed:
                             token_inv_case = getattr(token, case)()
                             return __get_value(token_inv_case, position, True)
-                        return handle_error(ename, errors, exc, lsep, repl_char, rminlen, decode)(token, position)
+                        return error_func(token, position)
+                    if isinstance(result, list):
+                        result = random.choice(result)
+                    return result + lsep
                 
                 # if a separator is defined, rely on it by splitting the input text
                 if decode and len(sep) > 0:
@@ -321,18 +350,20 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
                             # if the number of bad chars is the minimum token length, consume it and start a new buffer
                             if len(bad) == tminlen or errors == "leave":
                                 posn = cursor - len(bad)
-                                r += handle_error(ename, errors, exc, lsep, repl_char, rminlen, decode)(bad, posn)
+                                r += error_func(bad, posn)
                                 bad = ""
-                if binary and decode:
-                    tmp, r = "", r.replace(lsep, "")
-                    for i in range(0, len(r), 8):
-                        bs = r[i:i+8]
-                        try:
-                            tmp += chr(int(bs, 2))
-                        except ValueError:
-                            if len(bs) > 0:
-                                tmp += "[" + bs + "]"
-                    r = tmp + lsep
+                if decode:
+                    if outype in ["bin", "ord"]:
+                        tmp, r = "", r.replace(lsep, "")
+                        step = [3, 8][outype == "bin"]
+                        for i in range(0, len(r), step):
+                            s = r[i:i+step]
+                            try:
+                                tmp += chr(int(s, 2) if outype == "bin" else int(s))
+                            except ValueError:
+                                if len(s) > 0:
+                                    tmp += "[" + s + "]"
+                        r = tmp + lsep
                 return r[:len(r)-len(lsep)], len(b(text))
             return code
         if re.search(r"\([^(?:)]", kwargs.get('pattern', "")) is None:
@@ -340,22 +371,17 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
             return _wrapper(None)
         return _wrapper
 
-    name = "".join(t.capitalize() for t in re.split(r"[-_]", ename))
     glob = currentframe().f_back.f_globals
-    # dynamically make dedicated exception classes
-    decexc = "{}DecodeError".format(name)
-    exec("class {}(ValueError): pass".format(decexc), glob)
-    encexc = "{}EncodeError".format(name)
-    exec("class {}(ValueError): pass".format(encexc), glob)
-    # now use the generic add() function
-    kwargs['type'] = glob['__file__'].split(os.path.sep)[-2].rstrip("s")
+    kwargs['category'] = glob['__file__'].split(os.path.sep)[-2].rstrip("s")
     kwargs['examples'] = kwargs.get('examples', glob.get('__examples__'))
     kwargs['encmap'] = encmap
     kwargs['repl_char'] = repl_char
     kwargs['sep'] = sep
     kwargs['ignore_case'] = ignore_case
     kwargs['no_error'] = no_error
-    kwargs['binary'] = binary
+    kwargs['intype'] = intype
+    kwargs['outype'] = outype
+    kwargs['module'] = glob.get('__name__')
     try:
         if isinstance(encmap, dict):
             smapdict = {k: v for k, v in encmap.items()}
@@ -365,7 +391,7 @@ def add_map(ename, encmap, repl_char="?", sep="", ignore_case=None, no_error=Fal
         kwargs['repl_minlen_b'] = max(1, min(map(len, map(b, set(smapdict.values()) - {''}))))
     except:
         pass
-    add(ename, __generic_code(glob[encexc]), __generic_code(glob[decexc], True), **kwargs)
+    add(ename, __generic_code(), __generic_code(True), **kwargs)
 codecs.add_map = add_map
 
 
@@ -376,28 +402,38 @@ def clear():
 codecs.clear = clear
 
 
-def examples(encoding_regex, number=10):
+def examples(encoding, number=10):
     """ Use the search function to get the matching encodings and provide examples of valid encoding names. """
-    matches = search(encoding_regex)
-    examples = []
-    for n in matches:
+    e = []
+    for n in search(encoding):
         for search_function in __codecs_registry:
             if n == search_function.__name__:
                 temp = []
-                for s in generate_strings_from_regex(search_function.__pattern__, yield_max=256*number):
+                for s in generate_strings_from_regex(search_function.__pattern__, yield_max=16*number):
                     temp.append(s)
                 random.shuffle(temp)
-                examples.extend(sorted([temp[i] for i in range(min(number, len(temp)))], key=_human_keys))
-    return examples
+                i = 0
+                while i < min(number, len(temp)):
+                    if not temp[i].isdigit():
+                        e.append(temp[i])
+                    i += 1
+        for alias, codec in aliases.items():
+            if n == codec:
+                if codec not in e:
+                    e.append(codec)
+                if not alias.isdigit():
+                    e.append(alias)
+    random.shuffle(e)
+    return sorted([e[i] for i in range(min(number, len(e)))], key=_human_keys)
 codecs.examples = examples
 
 
 def list_encodings():
-    """ Get a list of codext's added encodings from the local registry. """
-    enc = []
+    """ Get a list of all codecs. """
+    enc = list(set(aliases.values()))
     for search_function in __codecs_registry:
-        enc.append(search_function.__name__)
-    return enc
+        enc.append(search_function.__name__.replace("_", "-"))
+    return sorted(list(set(enc)), key=_human_keys)
 
 
 def remove(encoding):
@@ -415,7 +451,10 @@ def reset():
     """ Reset codext's local registry of search functions. """
     global CODECS_REGISTRY, __codecs_registry
     clear()
-    for pkg in ["base", "crypto", "languages", "others", "stegano"]:
+    d = os.path.dirname(__file__)
+    for pkg in sorted(os.listdir(d)):
+        if pkg.startswith("_") or not os.path.isdir(os.path.join(d, pkg)):
+            continue
         reload(import_module("codext." + pkg))
     # backup codext's registry
     if CODECS_REGISTRY is None:
@@ -462,8 +501,7 @@ def fix_inout_formats(f):
         a0 = args[0]
         a0 = ensure_str(a0) if iss(a0) or isb(a0) else a0
         r = f(a0, *args[1:], **kwargs)
-        return (fix(r[0], args[0]), ) + r[1:] if isinstance(r, (tuple, list)) \
-               else fix(r, args[0])
+        return (fix(r[0], args[0]), ) + r[1:] if isinstance(r, (tuple, list)) else fix(r, args[0])
     return _wrapper
 
 
@@ -486,11 +524,34 @@ def get_alphabet_from_mask(mask):
 
 
 # generic error handling function
-def handle_error(ename, errors, exc=ValueError, sep="", repl_char="?", repl_minlen=1, decode=False, item="position"):
+def handle_error(ename, errors, sep="", repl_char="?", repl_minlen=1, decode=False, item="position"):
+    """
+    This shortcut function allows to handle error modes given some tuning parameters.
+    
+    :param ename:       encoding name
+    :param errors:      error handling mode
+    :param sep:         token separator
+    :param repl_char:   replacement character (for use when errors="replace")
+    :param repl_minlen: repeat number for the replacement character
+    :param decode:      whether we are encoding or decoding
+    :param item:        position item description (for describing the error ; e.g. "group" or "token")
+    """
+    name = "".join(t.capitalize() for t in re.split(r"[-_]", ename))
+    # dynamically make dedicated exception classes bound to the related codec module
+    exc = "%s%scodeError" % (name, ["En", "De"][decode])
+    glob = {'__name__': "__main__"}
+    exec("class %s(ValueError): pass" % exc, glob)
+    
     def _handle_error(token, position):
+        """
+        This handles an encoding/decoding error according to the selected handling mode.
+        
+        :param token:    input token to be encoded/decoded
+        :param position: token position index
+        """
         if errors == "strict":
-            raise exc("'{}' codec can't {}code character '{}' in {} {}"
-                      .format(ename, ["en", "de"][decode], token, item, position))
+            msg = "'{}' codec can't {}code character '{}' in {} {}"
+            raise glob[exc](msg.format(ename, ["en", "de"][decode], token, item, position))
         elif errors == "leave":
             return token + sep
         elif errors == "replace":
@@ -531,7 +592,9 @@ def lookup(encoding):
         codecinfo = search_function(encoding)
         if codecinfo is not None:
             return codecinfo
-    return __orig_lookup(encoding)
+    ci = __orig_lookup(encoding)
+    ci.parameters = {'category': "native", 'module': "codecs", 'name': aliases.get(ci.name, ci.name)}
+    return ci
 codecs.lookup = lookup
 
 
@@ -559,22 +622,33 @@ codecs.register = __register
 
 def search(encoding_regex):
     """ Function similar to lookup but allows to search for an encoding based on a regex instead. It searches this way
-     into the local registry but also tries a simple lookup with the original lookup function. """
+         into the local registry but also tries a simple lookup with the original lookup function. """
     matches = []
     for search_function in __codecs_registry:
         n = search_function.__name__
         if re.search(encoding_regex, n):
             matches.append(n)
             continue
-        for s in generate_strings_from_regex(search_function.__pattern__):
-            if re.search(encoding_regex, s):
+        # in some cases, encoding_regex can match a generated string that uses a particular portion of its generating
+        #  pattern ; e.g. we expect encoding_regex="uu_" to find "uu" and "uu_codec" while it can also find "morse" or
+        #  "atbash" very rarely because of their dynamic patterns and the limited number of randomly generated strings
+        # so, we can use a qualified majority voting to ensure we do not get a "junk" encoding in the list of matches ;
+        #  executing 5 times the string generation for a given codec but adding the codec to the list of matches only
+        #  if we get at least 3 matches ensures that we consider up to 2 failures that could be stochastic, therefore
+        #  drastically decreasing the probability to get a "junk" encoding in the matches list
+        c = 0
+        for i in range(5):
+            for s in generate_strings_from_regex(search_function.__pattern__):
+                if re.search(encoding_regex, s):
+                    c += 1
+                    break
+            if c >= 3:
                 matches.append(n)
                 break
-    try:
-        lookup(encoding_regex)
-        matches.append(encoding_regex)
-    except:
-        pass
+    for s, n in aliases.items():
+        if re.search(encoding_regex, s) or re.search(encoding_regex, n):
+            matches.append(n)
+            break
     return sorted(list(set(matches)), key=_human_keys)
 codecs.search = search
 
@@ -588,7 +662,7 @@ CATEGORIES = {
     'word':      ascii_letters + digits + '_',
     'not_word':  reduce(lambda x, c: x.replace(c, ""), ascii_letters + digits + '_', printable),
 }
-REPEAT_MAX    = 20
+REPEAT_MAX    = 10
 STAR_PLUS_MAX = 10
 YIELD_MAX     = 100
 
@@ -632,6 +706,7 @@ def __gen_str_from_re(regex, star_plus_max, repeat_max, yield_max, parsed=False)
         elif code in ["max_repeat", "min_repeat"]:
             start, end = value[:2]
             end = min(end, star_plus_max)
+            start = min(start, end)
             charset = list(__gen_str_from_re(value[-1], star_plus_max, repeat_max, yield_max, True))
             subtokens = []
             if start == 0 and end == 1:
