@@ -13,11 +13,7 @@ from ..__common__ import *
 
 
 if PY3:
-    class Base100Error(ValueError):
-        pass
-    
-    
-    class Base100DecodeError(Base100Error):
+    class Base100DecodeError(ValueError):
         pass
     
     
@@ -43,5 +39,5 @@ if PY3:
         return bytes(r), len(input)
     
     
-    add("base100", base100_encode, base100_decode, r"(?i)^(?:base[-_]?100|emoji)$")
+    add("base100", base100_encode, base100_decode, r"^(?:base[-_]?100|emoji)$")
 
