@@ -15,23 +15,23 @@ from ._base2n import base2n
 
 
 B2 = {r'': "01", r'[-_]inv(erted)?': "10"}
-base2n(B2, r"(?i)^(?:base[-_]?2|bin)(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{2})$")
+base2n(B2, r"^(?:base[-_]?2|bin)(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{2})$")
 
 
 B3 = {r'': "123", r'[-_]inv(erted)?': "321"}
-base(B3, r"(?i)^base[-_]?3(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{3})$")
+base(B3, r"^base[-_]?3(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{3})$")
 
 
 B4 = {r'': "1234", r'[-_]inv(erted)?': "4321"}
-base2n(B4, r"(?i)^base[-_]?4(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{4})$")
+base2n(B4, r"^base[-_]?4(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{4})$")
 
 
 B8 = {r'': "abcdefgh", r'[-_]inv(erted)?': "hgfedcba"}
-base2n(B8, r"(?i)^base[-_]?8(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{8})$")
+base2n(B8, r"^base[-_]?8(|[-_]inv(?:erted)?|[-_][a-zA-Z0-9]{8})$")
 
 
 B16 = {'': digits + "ABCDEF", 'inv': "ABCDEF" + digits}
-base2n(B16, r"(?i)^(?:base[-_]?16|hex)(|[-_]inv(?:erted)?)$")
+base2n(B16, r"^(?:base[-_]?16|hex)(|[-_]inv(?:erted)?)$")
 
 
 B32 = {
@@ -40,13 +40,13 @@ B32 = {
     r'(?:[-_]ext(?:ended)?)?[-_]hex$': digits + upper[:22],
     r'[-_]geohash':                    digits + "bcdefghjkmnpqrstuvwxyz",
 }
-base2n(B32, r"(?i)^base[-_]?32(|[-_]inv(?:erted)?|(?:[-_]ext(?:ended)?)?[-_]hex|[-_]geohash)$")
+base2n(B32, r"^base[-_]?32(|[-_]inv(?:erted)?|(?:[-_]ext(?:ended)?)?[-_]hex|[-_]geohash)$")
 ZB32 = {'': "ybndrfg8ejkmcpqxot1uwisza345h769"}
-base2n(ZB32, r"(?i)^z[-_]?base[-_]?32$")
+base2n(ZB32, r"^z[-_]?base[-_]?32$")
 
 
 B36 = {'': digits + upper, 'inv': upper + digits}
-base(B36, r"(?i)^base[-_]?36(|[-_]inv(?:erted)?)$")
+base(B36, r"^base[-_]?36(|[-_]inv(?:erted)?)$")
 
 
 B58 = {
@@ -54,11 +54,11 @@ B58 = {
     r'[-_](rp|ripple)$':                  "rpshnaf39wBUDNEGHJKLM4PQRST7VWXYZ2bcdeCg65jkm8oFqi1tuvAxyz",
     r'[-_](fl|flickr|short[-]?url|url)$': "123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ",
 }
-base(B58, r"(?i)^base[-_]?58(|[-_](bc|bitcoin|rp|ripple|fl|flickr|short[-]?url|url))$")
+base(B58, r"^base[-_]?58(|[-_](bc|bitcoin|rp|ripple|fl|flickr|short[-]?url|url))$")
 
 
 B62 = {'': digits + upper + lower, 'inv': digits + lower + upper}
-base(B62, r"(?i)^base[-_]?62(|[-_]inv(?:erted)?)$")
+base(B62, r"^base[-_]?62(|[-_]inv(?:erted)?)$")
 
 
 B64 = {
@@ -66,24 +66,9 @@ B64 = {
     r'[-_]inv(erted)?$':       lower + upper + digits + "+/",
     r'[-_](file|url)(safe)?$': upper + lower + digits + "-_",
 }
-base2n(B64, r"(?i)^base[-_]?64(|[-_]inv(?:erted)?|[-_](?:file|url)(?:safe)?)$")
-
-
-#FIXME
-#B85 = {
-#    r'':               "!\"#$%&'()*+,-./" + digits + ":;<=>?@" + upper + "[\\]^_`" + lower[:21],
-#    r'[-_]z(eromq)?$': digits + upper + lower + ".-:+=^!/*?&<>()[]{}@%$#",
-#    r'[-_]rfc1924$':   digits + upper + lower + "!#$%&()*+-;<=>?@^_`{|}~",
-#}
-#base(B85, r"(?i)^(?:ascii|base)[-_]?85(|[-_](?:z(?:eromq)?|rfc1924))$")
-
-
-B91 = {
-    '':    upper + lower + digits + "!#$%&()*+,./:;<=>?@[]^_`{|}~\"",
-    'inv': lower + upper + digits + "!#$%&()*+,./:;<=>?@[]^_`{|}~\"",
-}
-base(B91, r"(?i)^base[-_]?91(|[-_]inv(?:erted)?)$")
+base2n(B64, r"^base[-_]?64(|[-_]inv(?:erted)?|[-_](?:file|url)(?:safe)?)$")
 
 
 # generic base encodings, to be added after all others as they have the precedence
 base_generic()
+
