@@ -1,6 +1,9 @@
 # -*- coding: UTF-8 -*-
 from .braille import *
+from .leetspeak import *
 from .morse import *
+from .navajo import *
 from .radio import *
+from .southpark import *
 from .tomtom import *
 
