@@ -10,6 +10,12 @@ This codec:
 from ..__common__ import *
 
 
+__examples__ = {
+    'enc(radio|military-alphabet)':      {'test':   "Tango Echo Sierra Tango"},
+    'enc(nato-alphabet|radio-phonetic)': {'string': "Sierra Tango Romeo India November Golf"},
+}
+
+
 ENCMAP = {
     'A': "Alpha", 'B': "Bravo", 'C': "Charlie", 'D': "Delta", 'E': "Echo", 'F': "Foxtrot", 'G': "Golf", 'H': "Hotel",
     'I': "India", 'J': "Juliett", 'K': "Kilo", 'L': "Lima", 'M': "Mike", 'N': "November", 'O': "Oscar", 'P': "Papa",
@@ -19,5 +25,5 @@ ENCMAP = {
 
 
 add_map("radio", ENCMAP, sep=" ", ignore_case="both",
-        pattern=r"^(?:military|nato|radio)(?:[-_]phonetic)?[-_]alphabet?$")
+        pattern=r"^(?:military|nato|radio)(?:(?:[-_]phonetic)?(?:[-_]alphabet)?)?$")
 
